@@ -1,6 +1,5 @@
 package Mojolicious::Plugin::Crud;
 use Mojo::Base 'Mojolicious::Plugin';
-use Data::Dumper;
 
 use Lingua::EN::Inflect qw/PL/;
 use Mojo::Util qw( camelize );
@@ -8,7 +7,7 @@ use Mojo::Util qw( camelize );
 #------------------------------------------------------------------------------
 #   Crud 版本信息
 #------------------------------------------------------------------------------
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 #------------------------------------------------------------------------------
 #   Crud 插件注册方法
@@ -56,13 +55,13 @@ sub register {
       # 处理 "/$name/:id" 样式路由，GET DELETE PUT
       $resource = $r->under(
         "/$route_part/:id" => sub {
-          my ($c) = @_;
-          my $id = $c->param("id");
-          $c->app->log->debug( sprintf( "Storable: \$c->stash('form_id')->{'%s'} = %s", $name, $id ) );
+          my $c      = shift;
+          my %params = $c->req->params->to_hash();
+          $c->app->log->debug( sprintf( "Storable: \$c->stash('form_id')->{'%s'} = %s", $name, $params{"id"} ) );
 
           # 检查是否存在$c->stash('fm.ids')，并写入 URI 表单ID
           $c->stash( 'form_id' => {} ) unless $c->stash('form_id');
-          $c->stash('form_id')->{$name} = $c->param("id");
+          $c->stash('form_id')->{$name} = $params{"id"};
           return 1;
         }
       )->to( controller => $controller, idname => "id" );
